@@ -49,9 +49,9 @@ if __name__ == "__main__":
         # generated_M.to_csv(res_path / "random_nmf" / f"M_t{itrial}_nc{nb_clusters}_corrmin{round(min_corr,2)}_"
         #                                f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}.csv",
         #                    float_format="%.4f")
-        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=2, ncmax=45)
+        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=2, ncmax=10)
         df_mini_scree_plots = nmf.add_miniscree_plots_from_scree_plot(df_mini_scree_plots, df_scree_plot, nb_clusters)
 
-        if itrial % writefreq == 0:
-            output.write(df_mini_scree_plots)
+#        if itrial % writefreq == 0:
+    output.write(df_mini_scree_plots)
 
